/// Maps an emoji name to a corresponding glyph's URL.
var emojiNameToUrl = {
  /// GitHub emoji, as per GitHub's Emojis API.
  /// https://developer.github.com/v3/emojis/
  "+1": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44d.png?v5",
  "-1": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44e.png?v5",
  "100": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4af.png?v5",
  "1234": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f522.png?v5",
  "8ball": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b1.png?v5",
  "a": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f170.png?v5",
  "ab": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f18e.png?v5",
  "abc": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f524.png?v5",
  "abcd": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f521.png?v5",
  "accept": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f251.png?v5",
  "aerial_tramway": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a1.png?v5",
  "airplane": "https://assets-cdn.github.com/images/icons/emoji/unicode/2708.png?v5",
  "alarm_clock": "https://assets-cdn.github.com/images/icons/emoji/unicode/23f0.png?v5",
  "alien": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f47d.png?v5",
  "ambulance": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f691.png?v5",
  "anchor": "https://assets-cdn.github.com/images/icons/emoji/unicode/2693.png?v5",
  "angel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f47c.png?v5",
  "anger": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a2.png?v5",
  "angry": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f620.png?v5",
  "anguished": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f627.png?v5",
  "ant": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f41c.png?v5",
  "apple": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f34e.png?v5",
  "aquarius": "https://assets-cdn.github.com/images/icons/emoji/unicode/2652.png?v5",
  "aries": "https://assets-cdn.github.com/images/icons/emoji/unicode/2648.png?v5",
  "arrow_backward": "https://assets-cdn.github.com/images/icons/emoji/unicode/25c0.png?v5",
  "arrow_double_down": "https://assets-cdn.github.com/images/icons/emoji/unicode/23ec.png?v5",
  "arrow_double_up": "https://assets-cdn.github.com/images/icons/emoji/unicode/23eb.png?v5",
  "arrow_down": "https://assets-cdn.github.com/images/icons/emoji/unicode/2b07.png?v5",
  "arrow_down_small": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f53d.png?v5",
  "arrow_forward": "https://assets-cdn.github.com/images/icons/emoji/unicode/25b6.png?v5",
  "arrow_heading_down": "https://assets-cdn.github.com/images/icons/emoji/unicode/2935.png?v5",
  "arrow_heading_up": "https://assets-cdn.github.com/images/icons/emoji/unicode/2934.png?v5",
  "arrow_left": "https://assets-cdn.github.com/images/icons/emoji/unicode/2b05.png?v5",
  "arrow_lower_left": "https://assets-cdn.github.com/images/icons/emoji/unicode/2199.png?v5",
  "arrow_lower_right": "https://assets-cdn.github.com/images/icons/emoji/unicode/2198.png?v5",
  "arrow_right": "https://assets-cdn.github.com/images/icons/emoji/unicode/27a1.png?v5",
  "arrow_right_hook": "https://assets-cdn.github.com/images/icons/emoji/unicode/21aa.png?v5",
  "arrow_up": "https://assets-cdn.github.com/images/icons/emoji/unicode/2b06.png?v5",
  "arrow_up_down": "https://assets-cdn.github.com/images/icons/emoji/unicode/2195.png?v5",
  "arrow_up_small": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f53c.png?v5",
  "arrow_upper_left": "https://assets-cdn.github.com/images/icons/emoji/unicode/2196.png?v5",
  "arrow_upper_right": "https://assets-cdn.github.com/images/icons/emoji/unicode/2197.png?v5",
  "arrows_clockwise": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f503.png?v5",
  "arrows_counterclockwise": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f504.png?v5",
  "art": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a8.png?v5",
  "articulated_lorry": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f69b.png?v5",
  "astonished": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f632.png?v5",
  "athletic_shoe": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f45f.png?v5",
  "atm": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e7.png?v5",
  "b": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f171.png?v5",
  "baby": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f476.png?v5",
  "baby_bottle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f37c.png?v5",
  "baby_chick": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f424.png?v5",
  "baby_symbol": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6bc.png?v5",
  "back": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f519.png?v5",
  "baggage_claim": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6c4.png?v5",
  "balloon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f388.png?v5",
  "ballot_box_with_check": "https://assets-cdn.github.com/images/icons/emoji/unicode/2611.png?v5",
  "bamboo": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f38d.png?v5",
  "banana": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f34c.png?v5",
  "bangbang": "https://assets-cdn.github.com/images/icons/emoji/unicode/203c.png?v5",
  "bank": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e6.png?v5",
  "bar_chart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ca.png?v5",
  "barber": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f488.png?v5",
  "baseball": "https://assets-cdn.github.com/images/icons/emoji/unicode/26be.png?v5",
  "basketball": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c0.png?v5",
  "bath": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6c0.png?v5",
  "bathtub": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6c1.png?v5",
  "battery": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f50b.png?v5",
  "bear": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f43b.png?v5",
  "bee": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f41d.png?v5",
  "beer": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f37a.png?v5",
  "beers": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f37b.png?v5",
  "beetle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f41e.png?v5",
  "beginner": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f530.png?v5",
  "bell": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f514.png?v5",
  "bento": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f371.png?v5",
  "bicyclist": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b4.png?v5",
  "bike": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b2.png?v5",
  "bikini": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f459.png?v5",
  "bird": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f426.png?v5",
  "birthday": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f382.png?v5",
  "black_circle": "https://assets-cdn.github.com/images/icons/emoji/unicode/26ab.png?v5",
  "black_joker": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f0cf.png?v5",
  "black_large_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/2b1b.png?v5",
  "black_medium_small_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/25fe.png?v5",
  "black_medium_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/25fc.png?v5",
  "black_nib": "https://assets-cdn.github.com/images/icons/emoji/unicode/2712.png?v5",
  "black_small_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/25aa.png?v5",
  "black_square_button": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f532.png?v5",
  "blossom": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f33c.png?v5",
  "blowfish": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f421.png?v5",
  "blue_book": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d8.png?v5",
  "blue_car": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f699.png?v5",
  "blue_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f499.png?v5",
  "blush": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f60a.png?v5",
  "boar": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f417.png?v5",
  "boat": "https://assets-cdn.github.com/images/icons/emoji/unicode/26f5.png?v5",
  "bomb": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a3.png?v5",
  "book": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d6.png?v5",
  "bookmark": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f516.png?v5",
  "bookmark_tabs": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d1.png?v5",
  "books": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4da.png?v5",
  "boom": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a5.png?v5",
  "boot": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f462.png?v5",
  "bouquet": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f490.png?v5",
  "bow": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f647.png?v5",
  "bowling": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b3.png?v5",
  "bowtie": "https://assets-cdn.github.com/images/icons/emoji/bowtie.png?v5",
  "boy": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f466.png?v5",
  "bread": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f35e.png?v5",
  "bride_with_veil": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f470.png?v5",
  "bridge_at_night": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f309.png?v5",
  "briefcase": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4bc.png?v5",
  "broken_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f494.png?v5",
  "bug": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f41b.png?v5",
  "bulb": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a1.png?v5",
  "bullettrain_front": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f685.png?v5",
  "bullettrain_side": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f684.png?v5",
  "bus": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f68c.png?v5",
  "busstop": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f68f.png?v5",
  "bust_in_silhouette": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f464.png?v5",
  "busts_in_silhouette": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f465.png?v5",
  "cactus": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f335.png?v5",
  "cake": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f370.png?v5",
  "calendar": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c6.png?v5",
  "calling": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f2.png?v5",
  "camel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f42b.png?v5",
  "camera": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f7.png?v5",
  "cancer": "https://assets-cdn.github.com/images/icons/emoji/unicode/264b.png?v5",
  "candy": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f36c.png?v5",
  "capital_abcd": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f520.png?v5",
  "capricorn": "https://assets-cdn.github.com/images/icons/emoji/unicode/2651.png?v5",
  "car": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f697.png?v5",
  "card_index": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c7.png?v5",
  "carousel_horse": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a0.png?v5",
  "cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f431.png?v5",
  "cat2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f408.png?v5",
  "cd": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4bf.png?v5",
  "chart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b9.png?v5",
  "chart_with_downwards_trend": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c9.png?v5",
  "chart_with_upwards_trend": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c8.png?v5",
  "checkered_flag": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c1.png?v5",
  "cherries": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f352.png?v5",
  "cherry_blossom": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f338.png?v5",
  "chestnut": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f330.png?v5",
  "chicken": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f414.png?v5",
  "children_crossing": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b8.png?v5",
  "chocolate_bar": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f36b.png?v5",
  "christmas_tree": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f384.png?v5",
  "church": "https://assets-cdn.github.com/images/icons/emoji/unicode/26ea.png?v5",
  "cinema": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a6.png?v5",
  "circus_tent": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3aa.png?v5",
  "city_sunrise": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f307.png?v5",
  "city_sunset": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f306.png?v5",
  "cl": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f191.png?v5",
  "clap": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44f.png?v5",
  "clapper": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ac.png?v5",
  "clipboard": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4cb.png?v5",
  "clock1": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f550.png?v5",
  "clock10": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f559.png?v5",
  "clock1030": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f565.png?v5",
  "clock11": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f55a.png?v5",
  "clock1130": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f566.png?v5",
  "clock12": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f55b.png?v5",
  "clock1230": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f567.png?v5",
  "clock130": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f55c.png?v5",
  "clock2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f551.png?v5",
  "clock230": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f55d.png?v5",
  "clock3": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f552.png?v5",
  "clock330": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f55e.png?v5",
  "clock4": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f553.png?v5",
  "clock430": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f55f.png?v5",
  "clock5": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f554.png?v5",
  "clock530": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f560.png?v5",
  "clock6": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f555.png?v5",
  "clock630": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f561.png?v5",
  "clock7": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f556.png?v5",
  "clock730": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f562.png?v5",
  "clock8": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f557.png?v5",
  "clock830": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f563.png?v5",
  "clock9": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f558.png?v5",
  "clock930": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f564.png?v5",
  "closed_book": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d5.png?v5",
  "closed_lock_with_key": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f510.png?v5",
  "closed_umbrella": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f302.png?v5",
  "cloud": "https://assets-cdn.github.com/images/icons/emoji/unicode/2601.png?v5",
  "clubs": "https://assets-cdn.github.com/images/icons/emoji/unicode/2663.png?v5",
  "cn": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1e8-1f1f3.png?v5",
  "cocktail": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f378.png?v5",
  "coffee": "https://assets-cdn.github.com/images/icons/emoji/unicode/2615.png?v5",
  "cold_sweat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f630.png?v5",
  "collision": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a5.png?v5",
  "computer": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4bb.png?v5",
  "confetti_ball": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f38a.png?v5",
  "confounded": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f616.png?v5",
  "confused": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f615.png?v5",
  "congratulations": "https://assets-cdn.github.com/images/icons/emoji/unicode/3297.png?v5",
  "construction": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a7.png?v5",
  "construction_worker": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f477.png?v5",
  "convenience_store": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ea.png?v5",
  "cookie": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f36a.png?v5",
  "cool": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f192.png?v5",
  "cop": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f46e.png?v5",
  "copyright": "https://assets-cdn.github.com/images/icons/emoji/unicode/00a9.png?v5",
  "corn": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f33d.png?v5",
  "couple": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f46b.png?v5",
  "couple_with_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f491.png?v5",
  "couplekiss": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f48f.png?v5",
  "cow": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f42e.png?v5",
  "cow2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f404.png?v5",
  "credit_card": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b3.png?v5",
  "crescent_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f319.png?v5",
  "crocodile": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f40a.png?v5",
  "crossed_flags": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f38c.png?v5",
  "crown": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f451.png?v5",
  "cry": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f622.png?v5",
  "crying_cat_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f63f.png?v5",
  "crystal_ball": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f52e.png?v5",
  "cupid": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f498.png?v5",
  "curly_loop": "https://assets-cdn.github.com/images/icons/emoji/unicode/27b0.png?v5",
  "currency_exchange": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b1.png?v5",
  "curry": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f35b.png?v5",
  "custard": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f36e.png?v5",
  "customs": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6c3.png?v5",
  "cyclone": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f300.png?v5",
  "dancer": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f483.png?v5",
  "dancers": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f46f.png?v5",
  "dango": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f361.png?v5",
  "dart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3af.png?v5",
  "dash": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a8.png?v5",
  "date": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c5.png?v5",
  "de": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1e9-1f1ea.png?v5",
  "deciduous_tree": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f333.png?v5",
  "department_store": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ec.png?v5",
  "diamond_shape_with_a_dot_inside": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a0.png?v5",
  "diamonds": "https://assets-cdn.github.com/images/icons/emoji/unicode/2666.png?v5",
  "disappointed": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f61e.png?v5",
  "disappointed_relieved": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f625.png?v5",
  "dizzy": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ab.png?v5",
  "dizzy_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f635.png?v5",
  "do_not_litter": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6af.png?v5",
  "dog": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f436.png?v5",
  "dog2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f415.png?v5",
  "dollar": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b5.png?v5",
  "dolls": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f38e.png?v5",
  "dolphin": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f42c.png?v5",
  "door": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6aa.png?v5",
  "doughnut": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f369.png?v5",
  "dragon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f409.png?v5",
  "dragon_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f432.png?v5",
  "dress": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f457.png?v5",
  "dromedary_camel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f42a.png?v5",
  "droplet": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a7.png?v5",
  "dvd": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c0.png?v5",
  "e-mail": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e7.png?v5",
  "ear": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f442.png?v5",
  "ear_of_rice": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f33e.png?v5",
  "earth_africa": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f30d.png?v5",
  "earth_americas": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f30e.png?v5",
  "earth_asia": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f30f.png?v5",
  "egg": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f373.png?v5",
  "eggplant": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f346.png?v5",
  "eight": "https://assets-cdn.github.com/images/icons/emoji/unicode/0038-20e3.png?v5",
  "eight_pointed_black_star": "https://assets-cdn.github.com/images/icons/emoji/unicode/2734.png?v5",
  "eight_spoked_asterisk": "https://assets-cdn.github.com/images/icons/emoji/unicode/2733.png?v5",
  "electric_plug": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f50c.png?v5",
  "elephant": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f418.png?v5",
  "email": "https://assets-cdn.github.com/images/icons/emoji/unicode/2709.png?v5",
  "end": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f51a.png?v5",
  "envelope": "https://assets-cdn.github.com/images/icons/emoji/unicode/2709.png?v5",
  "envelope_with_arrow": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e9.png?v5",
  "es": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1ea-1f1f8.png?v5",
  "euro": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b6.png?v5",
  "european_castle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3f0.png?v5",
  "european_post_office": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e4.png?v5",
  "evergreen_tree": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f332.png?v5",
  "exclamation": "https://assets-cdn.github.com/images/icons/emoji/unicode/2757.png?v5",
  "expressionless": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f611.png?v5",
  "eyeglasses": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f453.png?v5",
  "eyes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f440.png?v5",
  "facepunch": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44a.png?v5",
  "factory": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ed.png?v5",
  "fallen_leaf": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f342.png?v5",
  "family": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f46a.png?v5",
  "fast_forward": "https://assets-cdn.github.com/images/icons/emoji/unicode/23e9.png?v5",
  "fax": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e0.png?v5",
  "fearful": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f628.png?v5",
  "feelsgood": "https://assets-cdn.github.com/images/icons/emoji/feelsgood.png?v5",
  "feet": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f43e.png?v5",
  "ferris_wheel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a1.png?v5",
  "file_folder": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c1.png?v5",
  "finnadie": "https://assets-cdn.github.com/images/icons/emoji/finnadie.png?v5",
  "fire": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f525.png?v5",
  "fire_engine": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f692.png?v5",
  "fireworks": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f386.png?v5",
  "first_quarter_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f313.png?v5",
  "first_quarter_moon_with_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f31b.png?v5",
  "fish": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f41f.png?v5",
  "fish_cake": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f365.png?v5",
  "fishing_pole_and_fish": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a3.png?v5",
  "fist": "https://assets-cdn.github.com/images/icons/emoji/unicode/270a.png?v5",
  "five": "https://assets-cdn.github.com/images/icons/emoji/unicode/0035-20e3.png?v5",
  "flags": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f38f.png?v5",
  "flashlight": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f526.png?v5",
  "flipper": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f42c.png?v5",
  "floppy_disk": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4be.png?v5",
  "flower_playing_cards": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b4.png?v5",
  "flushed": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f633.png?v5",
  "foggy": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f301.png?v5",
  "football": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c8.png?v5",
  "footprints": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f463.png?v5",
  "fork_and_knife": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f374.png?v5",
  "fountain": "https://assets-cdn.github.com/images/icons/emoji/unicode/26f2.png?v5",
  "four": "https://assets-cdn.github.com/images/icons/emoji/unicode/0034-20e3.png?v5",
  "four_leaf_clover": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f340.png?v5",
  "fr": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1eb-1f1f7.png?v5",
  "free": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f193.png?v5",
  "fried_shrimp": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f364.png?v5",
  "fries": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f35f.png?v5",
  "frog": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f438.png?v5",
  "frowning": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f626.png?v5",
  "fu": "https://assets-cdn.github.com/images/icons/emoji/fu.png?v5",
  "fuelpump": "https://assets-cdn.github.com/images/icons/emoji/unicode/26fd.png?v5",
  "full_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f315.png?v5",
  "full_moon_with_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f31d.png?v5",
  "game_die": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b2.png?v5",
  "gb": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1ec-1f1e7.png?v5",
  "gem": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f48e.png?v5",
  "gemini": "https://assets-cdn.github.com/images/icons/emoji/unicode/264a.png?v5",
  "ghost": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f47b.png?v5",
  "gift": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f381.png?v5",
  "gift_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f49d.png?v5",
  "girl": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f467.png?v5",
  "globe_with_meridians": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f310.png?v5",
  "goat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f410.png?v5",
  "goberserk": "https://assets-cdn.github.com/images/icons/emoji/goberserk.png?v5",
  "godmode": "https://assets-cdn.github.com/images/icons/emoji/godmode.png?v5",
  "golf": "https://assets-cdn.github.com/images/icons/emoji/unicode/26f3.png?v5",
  "grapes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f347.png?v5",
  "green_apple": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f34f.png?v5",
  "green_book": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d7.png?v5",
  "green_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f49a.png?v5",
  "grey_exclamation": "https://assets-cdn.github.com/images/icons/emoji/unicode/2755.png?v5",
  "grey_question": "https://assets-cdn.github.com/images/icons/emoji/unicode/2754.png?v5",
  "grimacing": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f62c.png?v5",
  "grin": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f601.png?v5",
  "grinning": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f600.png?v5",
  "guardsman": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f482.png?v5",
  "guitar": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b8.png?v5",
  "gun": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f52b.png?v5",
  "haircut": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f487.png?v5",
  "hamburger": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f354.png?v5",
  "hammer": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f528.png?v5",
  "hamster": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f439.png?v5",
  "hand": "https://assets-cdn.github.com/images/icons/emoji/unicode/270b.png?v5",
  "handbag": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f45c.png?v5",
  "hankey": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a9.png?v5",
  "hash": "https://assets-cdn.github.com/images/icons/emoji/unicode/0023-20e3.png?v5",
  "hatched_chick": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f425.png?v5",
  "hatching_chick": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f423.png?v5",
  "headphones": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a7.png?v5",
  "hear_no_evil": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f649.png?v5",
  "heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/2764.png?v5",
  "heart_decoration": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f49f.png?v5",
  "heart_eyes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f60d.png?v5",
  "heart_eyes_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f63b.png?v5",
  "heartbeat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f493.png?v5",
  "heartpulse": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f497.png?v5",
  "hearts": "https://assets-cdn.github.com/images/icons/emoji/unicode/2665.png?v5",
  "heavy_check_mark": "https://assets-cdn.github.com/images/icons/emoji/unicode/2714.png?v5",
  "heavy_division_sign": "https://assets-cdn.github.com/images/icons/emoji/unicode/2797.png?v5",
  "heavy_dollar_sign": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b2.png?v5",
  "heavy_exclamation_mark": "https://assets-cdn.github.com/images/icons/emoji/unicode/2757.png?v5",
  "heavy_minus_sign": "https://assets-cdn.github.com/images/icons/emoji/unicode/2796.png?v5",
  "heavy_multiplication_x": "https://assets-cdn.github.com/images/icons/emoji/unicode/2716.png?v5",
  "heavy_plus_sign": "https://assets-cdn.github.com/images/icons/emoji/unicode/2795.png?v5",
  "helicopter": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f681.png?v5",
  "herb": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f33f.png?v5",
  "hibiscus": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f33a.png?v5",
  "high_brightness": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f506.png?v5",
  "high_heel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f460.png?v5",
  "hocho": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f52a.png?v5",
  "honey_pot": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f36f.png?v5",
  "honeybee": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f41d.png?v5",
  "horse": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f434.png?v5",
  "horse_racing": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c7.png?v5",
  "hospital": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e5.png?v5",
  "hotel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e8.png?v5",
  "hotsprings": "https://assets-cdn.github.com/images/icons/emoji/unicode/2668.png?v5",
  "hourglass": "https://assets-cdn.github.com/images/icons/emoji/unicode/231b.png?v5",
  "hourglass_flowing_sand": "https://assets-cdn.github.com/images/icons/emoji/unicode/23f3.png?v5",
  "house": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e0.png?v5",
  "house_with_garden": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e1.png?v5",
  "hurtrealbad": "https://assets-cdn.github.com/images/icons/emoji/hurtrealbad.png?v5",
  "hushed": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f62f.png?v5",
  "ice_cream": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f368.png?v5",
  "icecream": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f366.png?v5",
  "id": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f194.png?v5",
  "ideograph_advantage": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f250.png?v5",
  "imp": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f47f.png?v5",
  "inbox_tray": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e5.png?v5",
  "incoming_envelope": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e8.png?v5",
  "information_desk_person": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f481.png?v5",
  "information_source": "https://assets-cdn.github.com/images/icons/emoji/unicode/2139.png?v5",
  "innocent": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f607.png?v5",
  "interrobang": "https://assets-cdn.github.com/images/icons/emoji/unicode/2049.png?v5",
  "iphone": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f1.png?v5",
  "it": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1ee-1f1f9.png?v5",
  "izakaya_lantern": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ee.png?v5",
  "jack_o_lantern": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f383.png?v5",
  "japan": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f5fe.png?v5",
  "japanese_castle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ef.png?v5",
  "japanese_goblin": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f47a.png?v5",
  "japanese_ogre": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f479.png?v5",
  "jeans": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f456.png?v5",
  "joy": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f602.png?v5",
  "joy_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f639.png?v5",
  "jp": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1ef-1f1f5.png?v5",
  "key": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f511.png?v5",
  "keycap_ten": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f51f.png?v5",
  "kimono": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f458.png?v5",
  "kiss": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f48b.png?v5",
  "kissing": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f617.png?v5",
  "kissing_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f63d.png?v5",
  "kissing_closed_eyes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f61a.png?v5",
  "kissing_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f618.png?v5",
  "kissing_smiling_eyes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f619.png?v5",
  "knife": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f52a.png?v5",
  "koala": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f428.png?v5",
  "koko": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f201.png?v5",
  "kr": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1f0-1f1f7.png?v5",
  "lantern": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ee.png?v5",
  "large_blue_circle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f535.png?v5",
  "large_blue_diamond": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f537.png?v5",
  "large_orange_diamond": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f536.png?v5",
  "last_quarter_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f317.png?v5",
  "last_quarter_moon_with_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f31c.png?v5",
  "laughing": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f606.png?v5",
  "leaves": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f343.png?v5",
  "ledger": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d2.png?v5",
  "left_luggage": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6c5.png?v5",
  "left_right_arrow": "https://assets-cdn.github.com/images/icons/emoji/unicode/2194.png?v5",
  "leftwards_arrow_with_hook": "https://assets-cdn.github.com/images/icons/emoji/unicode/21a9.png?v5",
  "lemon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f34b.png?v5",
  "leo": "https://assets-cdn.github.com/images/icons/emoji/unicode/264c.png?v5",
  "leopard": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f406.png?v5",
  "libra": "https://assets-cdn.github.com/images/icons/emoji/unicode/264e.png?v5",
  "light_rail": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f688.png?v5",
  "link": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f517.png?v5",
  "lips": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f444.png?v5",
  "lipstick": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f484.png?v5",
  "lock": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f512.png?v5",
  "lock_with_ink_pen": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f50f.png?v5",
  "lollipop": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f36d.png?v5",
  "loop": "https://assets-cdn.github.com/images/icons/emoji/unicode/27bf.png?v5",
  "loud_sound": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f50a.png?v5",
  "loudspeaker": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e2.png?v5",
  "love_hotel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e9.png?v5",
  "love_letter": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f48c.png?v5",
  "low_brightness": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f505.png?v5",
  "m": "https://assets-cdn.github.com/images/icons/emoji/unicode/24c2.png?v5",
  "mag": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f50d.png?v5",
  "mag_right": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f50e.png?v5",
  "mahjong": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f004.png?v5",
  "mailbox": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4eb.png?v5",
  "mailbox_closed": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ea.png?v5",
  "mailbox_with_mail": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ec.png?v5",
  "mailbox_with_no_mail": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ed.png?v5",
  "man": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f468.png?v5",
  "man_with_gua_pi_mao": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f472.png?v5",
  "man_with_turban": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f473.png?v5",
  "mans_shoe": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f45e.png?v5",
  "maple_leaf": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f341.png?v5",
  "mask": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f637.png?v5",
  "massage": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f486.png?v5",
  "meat_on_bone": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f356.png?v5",
  "mega": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e3.png?v5",
  "melon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f348.png?v5",
  "memo": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4dd.png?v5",
  "mens": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b9.png?v5",
  "metal": "https://assets-cdn.github.com/images/icons/emoji/metal.png?v5",
  "metro": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f687.png?v5",
  "microphone": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a4.png?v5",
  "microscope": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f52c.png?v5",
  "milky_way": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f30c.png?v5",
  "minibus": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f690.png?v5",
  "minidisc": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4bd.png?v5",
  "mobile_phone_off": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f4.png?v5",
  "money_with_wings": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b8.png?v5",
  "moneybag": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b0.png?v5",
  "monkey": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f412.png?v5",
  "monkey_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f435.png?v5",
  "monorail": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f69d.png?v5",
  "moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f314.png?v5",
  "mortar_board": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f393.png?v5",
  "mount_fuji": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f5fb.png?v5",
  "mountain_bicyclist": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b5.png?v5",
  "mountain_cableway": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a0.png?v5",
  "mountain_railway": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f69e.png?v5",
  "mouse": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f42d.png?v5",
  "mouse2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f401.png?v5",
  "movie_camera": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a5.png?v5",
  "moyai": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f5ff.png?v5",
  "muscle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4aa.png?v5",
  "mushroom": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f344.png?v5",
  "musical_keyboard": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b9.png?v5",
  "musical_note": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b5.png?v5",
  "musical_score": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3bc.png?v5",
  "mute": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f507.png?v5",
  "nail_care": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f485.png?v5",
  "name_badge": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4db.png?v5",
  "neckbeard": "https://assets-cdn.github.com/images/icons/emoji/neckbeard.png?v5",
  "necktie": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f454.png?v5",
  "negative_squared_cross_mark": "https://assets-cdn.github.com/images/icons/emoji/unicode/274e.png?v5",
  "neutral_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f610.png?v5",
  "new": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f195.png?v5",
  "new_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f311.png?v5",
  "new_moon_with_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f31a.png?v5",
  "newspaper": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f0.png?v5",
  "ng": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f196.png?v5",
  "night_with_stars": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f303.png?v5",
  "nine": "https://assets-cdn.github.com/images/icons/emoji/unicode/0039-20e3.png?v5",
  "no_bell": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f515.png?v5",
  "no_bicycles": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b3.png?v5",
  "no_entry": "https://assets-cdn.github.com/images/icons/emoji/unicode/26d4.png?v5",
  "no_entry_sign": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6ab.png?v5",
  "no_good": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f645.png?v5",
  "no_mobile_phones": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f5.png?v5",
  "no_mouth": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f636.png?v5",
  "no_pedestrians": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b7.png?v5",
  "no_smoking": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6ad.png?v5",
  "non-potable_water": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b1.png?v5",
  "nose": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f443.png?v5",
  "notebook": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d3.png?v5",
  "notebook_with_decorative_cover": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d4.png?v5",
  "notes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b6.png?v5",
  "nut_and_bolt": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f529.png?v5",
  "o": "https://assets-cdn.github.com/images/icons/emoji/unicode/2b55.png?v5",
  "o2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f17e.png?v5",
  "ocean": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f30a.png?v5",
  "octocat": "https://assets-cdn.github.com/images/icons/emoji/octocat.png?v5",
  "octopus": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f419.png?v5",
  "oden": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f362.png?v5",
  "office": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e2.png?v5",
  "ok": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f197.png?v5",
  "ok_hand": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44c.png?v5",
  "ok_woman": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f646.png?v5",
  "older_man": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f474.png?v5",
  "older_woman": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f475.png?v5",
  "on": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f51b.png?v5",
  "oncoming_automobile": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f698.png?v5",
  "oncoming_bus": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f68d.png?v5",
  "oncoming_police_car": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f694.png?v5",
  "oncoming_taxi": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f696.png?v5",
  "one": "https://assets-cdn.github.com/images/icons/emoji/unicode/0031-20e3.png?v5",
  "open_book": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d6.png?v5",
  "open_file_folder": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c2.png?v5",
  "open_hands": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f450.png?v5",
  "open_mouth": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f62e.png?v5",
  "ophiuchus": "https://assets-cdn.github.com/images/icons/emoji/unicode/26ce.png?v5",
  "orange_book": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d9.png?v5",
  "outbox_tray": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e4.png?v5",
  "ox": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f402.png?v5",
  "package": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e6.png?v5",
  "page_facing_up": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c4.png?v5",
  "page_with_curl": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4c3.png?v5",
  "pager": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4df.png?v5",
  "palm_tree": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f334.png?v5",
  "panda_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f43c.png?v5",
  "paperclip": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ce.png?v5",
  "parking": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f17f.png?v5",
  "part_alternation_mark": "https://assets-cdn.github.com/images/icons/emoji/unicode/303d.png?v5",
  "partly_sunny": "https://assets-cdn.github.com/images/icons/emoji/unicode/26c5.png?v5",
  "passport_control": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6c2.png?v5",
  "paw_prints": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f43e.png?v5",
  "peach": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f351.png?v5",
  "pear": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f350.png?v5",
  "pencil": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4dd.png?v5",
  "pencil2": "https://assets-cdn.github.com/images/icons/emoji/unicode/270f.png?v5",
  "penguin": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f427.png?v5",
  "pensive": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f614.png?v5",
  "performing_arts": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ad.png?v5",
  "persevere": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f623.png?v5",
  "person_frowning": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f64d.png?v5",
  "person_with_blond_hair": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f471.png?v5",
  "person_with_pouting_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f64e.png?v5",
  "phone": "https://assets-cdn.github.com/images/icons/emoji/unicode/260e.png?v5",
  "pig": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f437.png?v5",
  "pig2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f416.png?v5",
  "pig_nose": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f43d.png?v5",
  "pill": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f48a.png?v5",
  "pineapple": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f34d.png?v5",
  "pisces": "https://assets-cdn.github.com/images/icons/emoji/unicode/2653.png?v5",
  "pizza": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f355.png?v5",
  "point_down": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f447.png?v5",
  "point_left": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f448.png?v5",
  "point_right": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f449.png?v5",
  "point_up": "https://assets-cdn.github.com/images/icons/emoji/unicode/261d.png?v5",
  "point_up_2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f446.png?v5",
  "police_car": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f693.png?v5",
  "poodle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f429.png?v5",
  "poop": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a9.png?v5",
  "post_office": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3e3.png?v5",
  "postal_horn": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ef.png?v5",
  "postbox": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ee.png?v5",
  "potable_water": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b0.png?v5",
  "pouch": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f45d.png?v5",
  "poultry_leg": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f357.png?v5",
  "pound": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b7.png?v5",
  "pouting_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f63e.png?v5",
  "pray": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f64f.png?v5",
  "princess": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f478.png?v5",
  "punch": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44a.png?v5",
  "purple_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f49c.png?v5",
  "purse": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f45b.png?v5",
  "pushpin": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4cc.png?v5",
  "put_litter_in_its_place": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6ae.png?v5",
  "question": "https://assets-cdn.github.com/images/icons/emoji/unicode/2753.png?v5",
  "rabbit": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f430.png?v5",
  "rabbit2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f407.png?v5",
  "racehorse": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f40e.png?v5",
  "radio": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4fb.png?v5",
  "radio_button": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f518.png?v5",
  "rage": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f621.png?v5",
  "rage1": "https://assets-cdn.github.com/images/icons/emoji/rage1.png?v5",
  "rage2": "https://assets-cdn.github.com/images/icons/emoji/rage2.png?v5",
  "rage3": "https://assets-cdn.github.com/images/icons/emoji/rage3.png?v5",
  "rage4": "https://assets-cdn.github.com/images/icons/emoji/rage4.png?v5",
  "railway_car": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f683.png?v5",
  "rainbow": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f308.png?v5",
  "raised_hand": "https://assets-cdn.github.com/images/icons/emoji/unicode/270b.png?v5",
  "raised_hands": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f64c.png?v5",
  "raising_hand": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f64b.png?v5",
  "ram": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f40f.png?v5",
  "ramen": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f35c.png?v5",
  "rat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f400.png?v5",
  "recycle": "https://assets-cdn.github.com/images/icons/emoji/unicode/267b.png?v5",
  "red_car": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f697.png?v5",
  "red_circle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f534.png?v5",
  "registered": "https://assets-cdn.github.com/images/icons/emoji/unicode/00ae.png?v5",
  "relaxed": "https://assets-cdn.github.com/images/icons/emoji/unicode/263a.png?v5",
  "relieved": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f60c.png?v5",
  "repeat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f501.png?v5",
  "repeat_one": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f502.png?v5",
  "restroom": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6bb.png?v5",
  "revolving_hearts": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f49e.png?v5",
  "rewind": "https://assets-cdn.github.com/images/icons/emoji/unicode/23ea.png?v5",
  "ribbon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f380.png?v5",
  "rice": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f35a.png?v5",
  "rice_ball": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f359.png?v5",
  "rice_cracker": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f358.png?v5",
  "rice_scene": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f391.png?v5",
  "ring": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f48d.png?v5",
  "rocket": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f680.png?v5",
  "roller_coaster": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a2.png?v5",
  "rooster": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f413.png?v5",
  "rose": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f339.png?v5",
  "rotating_light": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a8.png?v5",
  "round_pushpin": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4cd.png?v5",
  "rowboat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a3.png?v5",
  "ru": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1f7-1f1fa.png?v5",
  "rugby_football": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c9.png?v5",
  "runner": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c3.png?v5",
  "running": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c3.png?v5",
  "running_shirt_with_sash": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3bd.png?v5",
  "sa": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f202.png?v5",
  "sagittarius": "https://assets-cdn.github.com/images/icons/emoji/unicode/2650.png?v5",
  "sailboat": "https://assets-cdn.github.com/images/icons/emoji/unicode/26f5.png?v5",
  "sake": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f376.png?v5",
  "sandal": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f461.png?v5",
  "santa": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f385.png?v5",
  "satellite": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4e1.png?v5",
  "satisfied": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f606.png?v5",
  "saxophone": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b7.png?v5",
  "school": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3eb.png?v5",
  "school_satchel": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f392.png?v5",
  "scissors": "https://assets-cdn.github.com/images/icons/emoji/unicode/2702.png?v5",
  "scorpius": "https://assets-cdn.github.com/images/icons/emoji/unicode/264f.png?v5",
  "scream": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f631.png?v5",
  "scream_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f640.png?v5",
  "scroll": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4dc.png?v5",
  "seat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ba.png?v5",
  "secret": "https://assets-cdn.github.com/images/icons/emoji/unicode/3299.png?v5",
  "see_no_evil": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f648.png?v5",
  "seedling": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f331.png?v5",
  "seven": "https://assets-cdn.github.com/images/icons/emoji/unicode/0037-20e3.png?v5",
  "shaved_ice": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f367.png?v5",
  "sheep": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f411.png?v5",
  "shell": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f41a.png?v5",
  "ship": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a2.png?v5",
  "shipit": "https://assets-cdn.github.com/images/icons/emoji/shipit.png?v5",
  "shirt": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f455.png?v5",
  "shit": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a9.png?v5",
  "shoe": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f45e.png?v5",
  "shower": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6bf.png?v5",
  "signal_strength": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f6.png?v5",
  "six": "https://assets-cdn.github.com/images/icons/emoji/unicode/0036-20e3.png?v5",
  "six_pointed_star": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f52f.png?v5",
  "ski": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3bf.png?v5",
  "skull": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f480.png?v5",
  "sleeping": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f634.png?v5",
  "sleepy": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f62a.png?v5",
  "slot_machine": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3b0.png?v5",
  "small_blue_diamond": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f539.png?v5",
  "small_orange_diamond": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f538.png?v5",
  "small_red_triangle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f53a.png?v5",
  "small_red_triangle_down": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f53b.png?v5",
  "smile": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f604.png?v5",
  "smile_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f638.png?v5",
  "smiley": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f603.png?v5",
  "smiley_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f63a.png?v5",
  "smiling_imp": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f608.png?v5",
  "smirk": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f60f.png?v5",
  "smirk_cat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f63c.png?v5",
  "smoking": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6ac.png?v5",
  "snail": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f40c.png?v5",
  "snake": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f40d.png?v5",
  "snowboarder": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c2.png?v5",
  "snowflake": "https://assets-cdn.github.com/images/icons/emoji/unicode/2744.png?v5",
  "snowman": "https://assets-cdn.github.com/images/icons/emoji/unicode/26c4.png?v5",
  "sob": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f62d.png?v5",
  "soccer": "https://assets-cdn.github.com/images/icons/emoji/unicode/26bd.png?v5",
  "soon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f51c.png?v5",
  "sos": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f198.png?v5",
  "sound": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f509.png?v5",
  "space_invader": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f47e.png?v5",
  "spades": "https://assets-cdn.github.com/images/icons/emoji/unicode/2660.png?v5",
  "spaghetti": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f35d.png?v5",
  "sparkle": "https://assets-cdn.github.com/images/icons/emoji/unicode/2747.png?v5",
  "sparkler": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f387.png?v5",
  "sparkles": "https://assets-cdn.github.com/images/icons/emoji/unicode/2728.png?v5",
  "sparkling_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f496.png?v5",
  "speak_no_evil": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f64a.png?v5",
  "speaker": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f508.png?v5",
  "speech_balloon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ac.png?v5",
  "speedboat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a4.png?v5",
  "squirrel": "https://assets-cdn.github.com/images/icons/emoji/shipit.png?v5",
  "star": "https://assets-cdn.github.com/images/icons/emoji/unicode/2b50.png?v5",
  "star2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f31f.png?v5",
  "stars": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f320.png?v5",
  "station": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f689.png?v5",
  "statue_of_liberty": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f5fd.png?v5",
  "steam_locomotive": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f682.png?v5",
  "stew": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f372.png?v5",
  "straight_ruler": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4cf.png?v5",
  "strawberry": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f353.png?v5",
  "stuck_out_tongue": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f61b.png?v5",
  "stuck_out_tongue_closed_eyes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f61d.png?v5",
  "stuck_out_tongue_winking_eye": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f61c.png?v5",
  "sun_with_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f31e.png?v5",
  "sunflower": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f33b.png?v5",
  "sunglasses": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f60e.png?v5",
  "sunny": "https://assets-cdn.github.com/images/icons/emoji/unicode/2600.png?v5",
  "sunrise": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f305.png?v5",
  "sunrise_over_mountains": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f304.png?v5",
  "surfer": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c4.png?v5",
  "sushi": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f363.png?v5",
  "suspect": "https://assets-cdn.github.com/images/icons/emoji/suspect.png?v5",
  "suspension_railway": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f69f.png?v5",
  "sweat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f613.png?v5",
  "sweat_drops": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a6.png?v5",
  "sweat_smile": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f605.png?v5",
  "sweet_potato": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f360.png?v5",
  "swimmer": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ca.png?v5",
  "symbols": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f523.png?v5",
  "syringe": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f489.png?v5",
  "tada": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f389.png?v5",
  "tanabata_tree": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f38b.png?v5",
  "tangerine": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f34a.png?v5",
  "taurus": "https://assets-cdn.github.com/images/icons/emoji/unicode/2649.png?v5",
  "taxi": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f695.png?v5",
  "tea": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f375.png?v5",
  "telephone": "https://assets-cdn.github.com/images/icons/emoji/unicode/260e.png?v5",
  "telephone_receiver": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4de.png?v5",
  "telescope": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f52d.png?v5",
  "tennis": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3be.png?v5",
  "tent": "https://assets-cdn.github.com/images/icons/emoji/unicode/26fa.png?v5",
  "thought_balloon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ad.png?v5",
  "three": "https://assets-cdn.github.com/images/icons/emoji/unicode/0033-20e3.png?v5",
  "thumbsdown": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44e.png?v5",
  "thumbsup": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44d.png?v5",
  "ticket": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ab.png?v5",
  "tiger": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f42f.png?v5",
  "tiger2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f405.png?v5",
  "tired_face": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f62b.png?v5",
  "tm": "https://assets-cdn.github.com/images/icons/emoji/unicode/2122.png?v5",
  "toilet": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6bd.png?v5",
  "tokyo_tower": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f5fc.png?v5",
  "tomato": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f345.png?v5",
  "tongue": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f445.png?v5",
  "top": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f51d.png?v5",
  "tophat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3a9.png?v5",
  "tractor": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f69c.png?v5",
  "traffic_light": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a5.png?v5",
  "train": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f68b.png?v5",
  "train2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f686.png?v5",
  "tram": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f68a.png?v5",
  "triangular_flag_on_post": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a9.png?v5",
  "triangular_ruler": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4d0.png?v5",
  "trident": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f531.png?v5",
  "triumph": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f624.png?v5",
  "trolleybus": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f68e.png?v5",
  "trollface": "https://assets-cdn.github.com/images/icons/emoji/trollface.png?v5",
  "trophy": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3c6.png?v5",
  "tropical_drink": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f379.png?v5",
  "tropical_fish": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f420.png?v5",
  "truck": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f69a.png?v5",
  "trumpet": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ba.png?v5",
  "tshirt": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f455.png?v5",
  "tulip": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f337.png?v5",
  "turtle": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f422.png?v5",
  "tv": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4fa.png?v5",
  "twisted_rightwards_arrows": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f500.png?v5",
  "two": "https://assets-cdn.github.com/images/icons/emoji/unicode/0032-20e3.png?v5",
  "two_hearts": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f495.png?v5",
  "two_men_holding_hands": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f46c.png?v5",
  "two_women_holding_hands": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f46d.png?v5",
  "u5272": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f239.png?v5",
  "u5408": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f234.png?v5",
  "u55b6": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f23a.png?v5",
  "u6307": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f22f.png?v5",
  "u6708": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f237.png?v5",
  "u6709": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f236.png?v5",
  "u6e80": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f235.png?v5",
  "u7121": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f21a.png?v5",
  "u7533": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f238.png?v5",
  "u7981": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f232.png?v5",
  "u7a7a": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f233.png?v5",
  "uk": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1ec-1f1e7.png?v5",
  "umbrella": "https://assets-cdn.github.com/images/icons/emoji/unicode/2614.png?v5",
  "unamused": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f612.png?v5",
  "underage": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f51e.png?v5",
  "unlock": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f513.png?v5",
  "up": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f199.png?v5",
  "us": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f1fa-1f1f8.png?v5",
  "v": "https://assets-cdn.github.com/images/icons/emoji/unicode/270c.png?v5",
  "vertical_traffic_light": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6a6.png?v5",
  "vhs": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4fc.png?v5",
  "vibration_mode": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f3.png?v5",
  "video_camera": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4f9.png?v5",
  "video_game": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3ae.png?v5",
  "violin": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f3bb.png?v5",
  "virgo": "https://assets-cdn.github.com/images/icons/emoji/unicode/264d.png?v5",
  "volcano": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f30b.png?v5",
  "vs": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f19a.png?v5",
  "walking": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6b6.png?v5",
  "waning_crescent_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f318.png?v5",
  "waning_gibbous_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f316.png?v5",
  "warning": "https://assets-cdn.github.com/images/icons/emoji/unicode/26a0.png?v5",
  "watch": "https://assets-cdn.github.com/images/icons/emoji/unicode/231a.png?v5",
  "water_buffalo": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f403.png?v5",
  "watermelon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f349.png?v5",
  "wave": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f44b.png?v5",
  "wavy_dash": "https://assets-cdn.github.com/images/icons/emoji/unicode/3030.png?v5",
  "waxing_crescent_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f312.png?v5",
  "waxing_gibbous_moon": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f314.png?v5",
  "wc": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6be.png?v5",
  "weary": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f629.png?v5",
  "wedding": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f492.png?v5",
  "whale": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f433.png?v5",
  "whale2": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f40b.png?v5",
  "wheelchair": "https://assets-cdn.github.com/images/icons/emoji/unicode/267f.png?v5",
  "white_check_mark": "https://assets-cdn.github.com/images/icons/emoji/unicode/2705.png?v5",
  "white_circle": "https://assets-cdn.github.com/images/icons/emoji/unicode/26aa.png?v5",
  "white_flower": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4ae.png?v5",
  "white_large_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/2b1c.png?v5",
  "white_medium_small_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/25fd.png?v5",
  "white_medium_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/25fb.png?v5",
  "white_small_square": "https://assets-cdn.github.com/images/icons/emoji/unicode/25ab.png?v5",
  "white_square_button": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f533.png?v5",
  "wind_chime": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f390.png?v5",
  "wine_glass": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f377.png?v5",
  "wink": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f609.png?v5",
  "wolf": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f43a.png?v5",
  "woman": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f469.png?v5",
  "womans_clothes": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f45a.png?v5",
  "womans_hat": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f452.png?v5",
  "womens": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f6ba.png?v5",
  "worried": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f61f.png?v5",
  "wrench": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f527.png?v5",
  "x": "https://assets-cdn.github.com/images/icons/emoji/unicode/274c.png?v5",
  "yellow_heart": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f49b.png?v5",
  "yen": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4b4.png?v5",
  "yum": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f60b.png?v5",
  "zap": "https://assets-cdn.github.com/images/icons/emoji/unicode/26a1.png?v5",
  "zero": "https://assets-cdn.github.com/images/icons/emoji/unicode/0030-20e3.png?v5",
  "zzz": "https://assets-cdn.github.com/images/icons/emoji/unicode/1f4a4.png?v5"
};